-----------------------------------------------------------------------------------------------
-- Client Lua Script for MOTDOnLogin
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"

-----------------------------------------------------------------------------------------------
-- MOTDOnLogin Module Definition
-----------------------------------------------------------------------------------------------
local MOTDOnLogin = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
MOTDOnLogin.ShowMessageTime = 10
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function MOTDOnLogin:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function MOTDOnLogin:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- MOTDOnLogin OnLoad
-----------------------------------------------------------------------------------------------
function MOTDOnLogin:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("MOTDOnLogin.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- MOTDOnLogin OnDocLoaded
-----------------------------------------------------------------------------------------------
function MOTDOnLogin:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "MOTDOnLoginForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end

		-- if the xmlDoc is no longer needed, you should set it to nil
		--self.xmlDoc = nil
		self.wndMain:Show(false, true)
		self.txtMOTD = self.wndMain:FindChild("txtMOTD")
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("motd", "OnMOTDOnLoginOn", self)
		Apollo.RegisterTimerHandler("MOTDOnLoginTimer","OnMOTDOnLoginTimer",self)
		
		self:OnMOTDOnLoginOn()
	end
end

-----------------------------------------------------------------------------------------------
-- MOTDOnLogin Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/motd"
function MOTDOnLogin:OnMOTDOnLoginOn()
	
	if self.txtMOTD ~= nil then
		self.txtMOTD:SetText(MOTDOnLogin:GetMOTD())
	end
	
	self.wndMain:Invoke()
	self.timer = Apollo.CreateTimer("MOTDOnLoginTimer", MOTDOnLogin.ShowMessageTime, false)
	Apollo.StartTimer("MOTDOnLoginTimer")
end


-----------------------------------------------------------------------------------------------
-- MOTDOnLoginForm Functions
-----------------------------------------------------------------------------------------------
function MOTDOnLogin:GetMOTD()
	--Print("Get motd")
	-- Get the current user's guild and print the MOTD
	local _guilds = GuildLib.GetGuilds()
	for idx, guild in ipairs(_guilds) do
		if guild:GetType() == GuildLib.GuildType_Guild then
			return guild:GetMessageOfTheDay()
		end
	end
	
	return "You are not in a guild"
end

-- when the Cancel button is clicked
function MOTDOnLogin:OnCancel()
	self.wndMain:Close() -- hide the window
end

function MOTDOnLogin:OnMOTDOnLoginTimer()
	--Print("Timer!")
	self.wndMain:Close()
	Apollo.StopTimer(self.timer)
end

-----------------------------------------------------------------------------------------------
-- MOTDOnLogin Instance
-----------------------------------------------------------------------------------------------
local MOTDOnLoginInst = MOTDOnLogin:new()
MOTDOnLoginInst:Init()
